#!/usr/bin/env python3

import argparse
import subprocess
import tempfile
import os


def mix(args):
    interval = '%d.%d' % (args.interval / 60, args.interval % 60)
    with tempfile.TemporaryDirectory(prefix='audiobanner') as tempdir:
        subprocess.check_call(['mp3splt', '-d', tempdir,
                               '-o', 'orig_@n_@m.mp3',
                               '-t', interval,
                               args.original])
        parts = []
        if args.intro:
            parts.append(args.intro)
        for part in sorted(os.listdir(tempdir)):
            parts += [os.path.join(tempdir, part),
                      args.banner]
        parts.pop()
        if args.outro:
            parts.append(args.outro)

        ffmpegconcat = 'concat:%s' % "|".join(parts)

        cmd = ['ffmpeg', '-i', ffmpegconcat,
               '-loglevel', 'error', '-n',
               args.destination]
        subprocess.check_call(cmd)


def get_parser():
    p = argparse.ArgumentParser("audiobanner")
    p.add_argument("--interval", help='In seconds', default=600, type=int)
    p.add_argument("--intro", type=str)
    p.add_argument("--outro", type=str)
    p.add_argument("original")
    p.add_argument("banner")
    p.add_argument("destination")
    return p


def main():
    args = get_parser().parse_args()
    mix(args)


if __name__ == '__main__':
    main()
